@@ -237,8 +237,10 @@ class Server:
             return
 
     def disconnect(self, connection_token: str) -> None:
-        del self.buffers[connection_token]
-        del self.connections[connection_token]
+        if connection_token in self.buffers:
+            del self.buffers[connection_token]
+        if connection_token in self.connections:
+            del self.connections[connection_token]
 
     def run(self):
         loop = asyncio.get_event_loop()
