@@ -135,9 +135,8 @@ def non_unix_timed_input(message: str = None,
     return
 
 
-def timed_input(message: str = None,
-                timeout: int = 5):
-    """Print `message` and return input within `timeout` seconds."""
-    if sys.platform.startswith('linux'):
-        return unix_timed_input(message=message, timeout=timeout)
-    return non_unix_timed_input(message=message, timeout=timeout)
+timed_input = (
+    unix_timed_input
+    if sys.platform.startswith('linux')
+    else non_unix_timed_input()
+)
